package org.eclipse.jdt.internal.compiler.apt.util;

import java.io.FileWriter;
import java.io.Writer;
import java.io.FileReader;
import java.io.Reader;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.io.FileInputStream;
import java.io.InputStream;
import org.eclipse.jdt.internal.compiler.util.Util;
import javax.lang.model.element.NestingKind;
import java.io.IOException;
import org.eclipse.jdt.internal.compiler.classfmt.ClassFormatException;
import org.eclipse.jdt.internal.compiler.classfmt.ClassFileReader;
import javax.lang.model.element.Modifier;
import javax.tools.JavaFileObject;
import java.net.URI;
import java.nio.charset.Charset;
import java.io.File;
import javax.tools.SimpleJavaFileObject;

public class EclipseFileObject extends SimpleJavaFileObject
{
    private File f;
    private Charset charset;
    private boolean parentsExist;
    private static /* synthetic */ int[] $SWITCH_TABLE$javax$tools$JavaFileObject$Kind;
    
    public EclipseFileObject(String className, URI uri, JavaFileObject.Kind kind, Charset charset) {
        super(uri, kind);
        this.f = new File(this.uri);
        this.charset = charset;
        this.parentsExist = false;
    }
    
    @Override
    public Modifier getAccessLevel() {
        if (this.getKind() != JavaFileObject.Kind.CLASS) {
            return null;
        }
        ClassFileReader reader = null;
        try {
            reader = ClassFileReader.read(this.f);
        }
        catch (ClassFormatException ex) {}
        catch (IOException ex2) {}
        if (reader == null) {
            return null;
        }
        int accessFlags = reader.accessFlags();
        if ((accessFlags & 0x1) != 0x0) {
            return Modifier.PUBLIC;
        }
        if ((accessFlags & 0x400) != 0x0) {
            return Modifier.ABSTRACT;
        }
        if ((accessFlags & 0x10) != 0x0) {
            return Modifier.FINAL;
        }
        return null;
    }
    
    @Override
    public NestingKind getNestingKind() {
        switch ($SWITCH_TABLE$javax$tools$JavaFileObject$Kind()[this.kind.ordinal()]) {
            case 1: {
                return NestingKind.TOP_LEVEL;
            }
            case 2: {
                ClassFileReader reader = null;
                try {
                    reader = ClassFileReader.read(this.f);
                }
                catch (ClassFormatException ex) {}
                catch (IOException ex2) {}
                if (reader == null) {
                    return null;
                }
                if (reader.isAnonymous()) {
                    return NestingKind.ANONYMOUS;
                }
                if (reader.isLocal()) {
                    return NestingKind.LOCAL;
                }
                if (reader.isMember()) {
                    return NestingKind.MEMBER;
                }
                return NestingKind.TOP_LEVEL;
            }
            default: {
                return null;
            }
        }
    }
    
    @Override
    public boolean delete() {
        return this.f.delete();
    }
    
    @Override
    public boolean equals(Object o) {
        if (!(o instanceof EclipseFileObject)) {
            return false;
        }
        EclipseFileObject eclipseFileObject = (EclipseFileObject)o;
        return eclipseFileObject.toUri().equals(this.uri);
    }
    
    @Override
    public CharSequence getCharContent(boolean ignoreEncodingErrors) throws IOException {
        return org.eclipse.jdt.internal.compiler.apt.util.Util.getCharContents(this, ignoreEncodingErrors, Util.getFileByteContent(this.f), this.charset.name());
    }
    
    @Override
    public long getLastModified() {
        return this.f.lastModified();
    }
    
    @Override
    public String getName() {
        return this.f.getPath();
    }
    
    @Override
    public int hashCode() {
        return this.f.hashCode();
    }
    
    @Override
    public InputStream openInputStream() throws IOException {
        return new FileInputStream(this.f);
    }
    
    @Override
    public OutputStream openOutputStream() throws IOException {
        this.ensureParentDirectoriesExist();
        return new FileOutputStream(this.f);
    }
    
    @Override
    public Reader openReader(boolean ignoreEncodingErrors) throws IOException {
        return new FileReader(this.f);
    }
    
    @Override
    public Writer openWriter() throws IOException {
        this.ensureParentDirectoriesExist();
        return new FileWriter(this.f);
    }
    
    @Override
    public String toString() {
        return this.f.getAbsolutePath();
    }
    
    private void ensureParentDirectoriesExist() throws IOException {
        if (!this.parentsExist) {
            File parent = this.f.getParentFile();
            if (parent != null && !parent.exists() && !parent.mkdirs() && (!parent.exists() || !parent.isDirectory())) {
                throw new IOException("Unable to create parent directories for " + this.f);
            }
            this.parentsExist = true;
        }
    }
    
    static /* synthetic */ int[] $SWITCH_TABLE$javax$tools$JavaFileObject$Kind() {
        int[] $switch_TABLE$javax$tools$JavaFileObject$Kind = EclipseFileObject.$SWITCH_TABLE$javax$tools$JavaFileObject$Kind;
        if ($switch_TABLE$javax$tools$JavaFileObject$Kind != null) {
            return $switch_TABLE$javax$tools$JavaFileObject$Kind;
        }
        int[] $switch_TABLE$javax$tools$JavaFileObject$Kind2 = new int[JavaFileObject.Kind.values().length];
        try {
            $switch_TABLE$javax$tools$JavaFileObject$Kind2[JavaFileObject.Kind.CLASS.ordinal()] = 2;
        }
        catch (NoSuchFieldError noSuchFieldError) {}
        try {
            $switch_TABLE$javax$tools$JavaFileObject$Kind2[JavaFileObject.Kind.HTML.ordinal()] = 3;
        }
        catch (NoSuchFieldError noSuchFieldError2) {}
        try {
            $switch_TABLE$javax$tools$JavaFileObject$Kind2[JavaFileObject.Kind.OTHER.ordinal()] = 4;
        }
        catch (NoSuchFieldError noSuchFieldError3) {}
        try {
            $switch_TABLE$javax$tools$JavaFileObject$Kind2[JavaFileObject.Kind.SOURCE.ordinal()] = 1;
        }
        catch (NoSuchFieldError noSuchFieldError4) {}
        return EclipseFileObject.$SWITCH_TABLE$javax$tools$JavaFileObject$Kind = $switch_TABLE$javax$tools$JavaFileObject$Kind2;
    }
}
